
 // requires spawn flag
 public Devotion_Aura(id, skill, prop)
 {
	// get the players maxhp
	new maxhp = PlayerStat[id][STAT_MAXHP];

	// add some more based on the skills level
	maxhp += SkillClamp(id, skill, 10, 40);

	// set the new maxhp
	PlayerStat[id][STAT_MAXHP] = maxhp;

	// check the maxhp so that it matches server standards
	CheckMaxHP(id);

	// let pokemod know the skill was used
	return SKILL_USED;
 }

 // requires reset flag
 public Healing_Wave(id, skill, prop)
 {
	// if they switch pokemon, we dont want to call the skill for them anymore
	if( prop & SI_RESET ){
		RemoveDelayCallSkill(id, skill);
		DelayedCallSkill( 0.1, id, skill, SI_SKILLCALL);
		return SKILL_READY;
	}

	// if they dont have the skill
	if( !SkillLevel(id, skill) || !Pokemod_Alive(id) )
		// let pokemod know the skill was not used
		return SKILL_READY;

	// get a list of all players on the same team
	new players[MAX_PLAYERS], pnum, aid;
	poke_get_players( players, pnum, PLAYER_INTEAM, Pokemod_Team(id) );

	// some things for the skill to use
	new heal_amount = 1;
	new radius = 750;

	// loop through all the players found
	for( new i=0; i<pnum; i++ ){
		aid = players[i];

		// check if the range between players is within the radius
		if( fm_entity_range(id, aid) < radius ){

			// heal the player
			Pokemod_Heal(aid, heal_amount);

		}

	}

	// get the time until the skill will be called again
	new Float:delay_time = f_SkillClamp( id, skill, 6.0, 1.5 );

	// call the skill again
	DelayedCallSkill( delay_time, id, skill, SI_SKILLCALL);

	// let pokemod know the skill was used
	return SKILL_USED;
 }

 // requires attack flag
 public Vampiric_Aura(id, skill, prop)
 {
	// get the damage that was done
	new damage;
	PokeSkillTarget(id, damage);

	// get how much we should heal
	new heal = floatround( f_SkillClamp(id, skill, damage*0.1, damage*0.34 ) );

	// heal the person with the skill
	Pokemod_Heal(id, heal);

	// let pokemod know the skill was used
	return SKILL_USED;
 }

 // requires reset and loop flags
 public Invisibility(id, skill, prop)
 {
	// if we are reseting the skill
	if( prop & SI_RESET ){

		// reset their visibility
		set_user_rendering(id);

		// let pokemod know the skill was not used
		return SKILL_READY;
	}

	//if they have the skill active
	if( SkillLevel(id, skill) ){

		// get the level of invisibility
		new visibility = SkillClamp( id, skill, 225, 135 );

		// if they have knife out
		if( knife_weapon( get_user_weapon(id) ) )
			//make their visibility half
			visibility /= 2;

		// set them to the visibility
		fm_set_rendering(id, kRenderFxGlowShell, 0, 0, 0, kRenderTransAlpha, visibility);

		// let pokemod know the skill was used
		return SKILL_USED;

	}

	// skill is not active, so restore them to normal visibility
	else set_user_rendering(id);

	// let pokemod know the skill was not used
	return SKILL_READY;
 }

 public Custom(id, skill, prop)
 {
	// let pokemod know the skill was used
	return SKILL_USED;
 }